from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .claim_operator import ClaimOperator

@dataclass
class ClaimRule(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The claim property
    claim: Optional[str] = None
    # The operator property
    operator: Optional[ClaimOperator] = None
    # The value property
    value: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> ClaimRule:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: ClaimRule
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return ClaimRule()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .claim_operator import ClaimOperator

        from .claim_operator import ClaimOperator

        fields: dict[str, Callable[[Any], None]] = {
            "claim": lambda n : setattr(self, 'claim', n.get_str_value()),
            "operator": lambda n : setattr(self, 'operator', n.get_enum_value(ClaimOperator)),
            "value": lambda n : setattr(self, 'value', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("claim", self.claim)
        writer.write_enum_value("operator", self.operator)
        writer.write_str_value("value", self.value)
        writer.write_additional_data_value(self.additional_data)
    

